# - A script to turn a VR Juggler app target into a Mac OS X bundle
#
#  add_vrjuggler_bundle_sources(SOURCES_VAR_NAME) - run before add_executable
#  finish_vrjuggler_bundle(TARGET_NAME LIB_DIRS) - run after add_executable
#
# 2009 Ryan Pavlik <rpavlik@iastate.edu>
# http://academic.cleardefinition.com
# Iowa State University HCI Graduate Program/VRAC

function(add_vrjuggler_bundle_sources _target_sources)
	if(APPLE)
		if(NOT MACOSX_PACKAGE_DIR)
			set(MACOSX_PACKAGE_DIR ${CMAKE_SOURCE_DIR}/cmake/package/macosx)
		endif()
		
		# Append Mac-specific sources to source list
		set(${_target_sources} 
			${${_target_sources}}
			${MACOSX_PACKAGE_DIR}/Resources/vrjuggler.icns
			${MACOSX_PACKAGE_DIR}/Resources/vrjuggler.plist
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/classes.nib
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/info.nib
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/keyedobjects.nib
			PARENT_SCOPE)
			
		# Set destination of nib files
		set_source_files_properties(
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/classes.nib
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/info.nib
			${MACOSX_PACKAGE_DIR}/Resources/en.lproj/MainMenu.nib/keyedobjects.nib
			PROPERTIES
			MACOSX_PACKAGE_LOCATION Resources/en.lproj/MainMenu.nib/)
		
		# Set destination of Resources
		set_source_files_properties(
			${MACOSX_PACKAGE_DIR}/Resources/vrjuggler.icns
			${MACOSX_PACKAGE_DIR}/Resources/vrjuggler.plist
			PROPERTIES
			MACOSX_PACKAGE_LOCATION Resources/)
		
	endif()
endfunction()

function(finish_vrjuggler_bundle _target _libdirs)
	if(APPLE)
		if(NOT MACOSX_PACKAGE_DIR)
			set(MACOSX_PACKAGE_DIR ${CMAKE_SOURCE_DIR}/cmake/package/macosx)
		endif()
		set_target_properties(${_target} PROPERTIES
			MACOSX_BUNDLE true
			MACOSX_BUNDLE_INFO_PLIST ${MACOSX_PACKAGE_DIR}/VRJuggler22BundleInfo.plist.in
			MACOSX_BUNDLE_ICON_FILE vrjuggler.icns
			MACOSX_BUNDLE_INFO_STRING "${PROJECT_NAME} (VR Juggler Application) version ${CPACK_PACKAGE_VERSION}, created by ${CPACK_PACKAGE_VENDOR}" 
			MACOSX_BUNDLE_GUI_IDENTIFIER org.vrjuggler.${PROJECT_NAME}
			MACOSX_BUNDLE_SHORT_VERSION_STRING ${CPACK_PACKAGE_VERSION}
			MACOSX_BUNDLE_BUNDLE_VERSION ${CPACK_PACKAGE_VERSION})

		set(BUNDLE_LIBS libboost_filesystem-1_34_1.dylib libboost_signals-1_34_1.dylib)
		set(BUNDLE_LIB_DIRS ${_libdirs})
		
		configure_file(${MACOSX_PACKAGE_DIR}/fixupbundle.cmake.in
			${CMAKE_CURRENT_BINARY_DIR}/${_target}-fixupbundle.cmake
			@ONLY)
		add_custom_command(TARGET ${_target}
			POST_BUILD
			COMMAND ${CMAKE_COMMAND} -P ${CMAKE_CURRENT_BINARY_DIR}/${_target}-fixupbundle.cmake
			VERBATIM)

	endif()
endfunction()
